@@ -658,7 +658,6 @@ peas_extension_set_new_valist (PeasEngine  *engine,
                                const gchar *first_property,
                                va_list      var_args)
 {
-  gpointer type_struct;
   GParameter *parameters;
   guint n_parameters;
   PeasExtensionSet *set;
@@ -666,13 +665,10 @@ peas_extension_set_new_valist (PeasEngine  *engine,
   g_return_val_if_fail (engine == NULL || PEAS_IS_ENGINE (engine), NULL);
   g_return_val_if_fail (G_TYPE_IS_INTERFACE (exten_type), NULL);
 
-  type_struct = _g_type_struct_ref (exten_type);
-
-  if (!_valist_to_parameter_list (exten_type, type_struct, first_property,
+  if (!_valist_to_parameter_list (exten_type, first_property,
                                   var_args, &parameters, &n_parameters))
     {
       /* Already warned */
-      _g_type_struct_unref (exten_type, type_struct);
       return NULL;
     }
 
@@ -682,8 +678,6 @@ peas_extension_set_new_valist (PeasEngine  *engine,
     g_value_unset (&parameters[n_parameters].value);
   g_free (parameters);
 
-  _g_type_struct_unref (exten_type, type_struct);
-
   return set;
 }
 
