@@ -283,8 +283,12 @@ peas_extension_gjs_call (PeasExtensionWrapper *exten,
 
   if (!success)
     {
-      g_warning ("Error while calling '%s.%s'",
-                 g_type_name (exten_type), method_name);
+      if (!gjs_log_exception (gexten->js_context, NULL))
+        {
+          g_warning ("Error while calling '%s.%s'",
+                     g_type_name (exten_type), method_name);
+        }
+
       return FALSE;
     }
 
